# Change log

## Unreleased

- Stopped interleaving `print()` statements from different compression threads.
- Started running the testsuite using GitHub actions.
- Don't crash when compressing if brotli isn't installed.

## 1.0 (2024-05-18)

- I'm declaring this package to be production-ready.
